@@ -6,4 +6,6 @@ pub mod errors;
 pub mod io;
 #[macro_use]
 pub mod defer;
-pub mod time;
\ No newline at end of file
+pub mod time;
+pub mod map;
+pub mod strings;
\ No newline at end of file
